@@ -32,7 +32,7 @@
 
 class dlg_promote : public TQDialog
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 	public:
 
