@@ -79,9 +79,9 @@ int logic::CalcPointer( const char File, const char Rank )
 bool logic::isChessman( const char ChessmanPtr )
 {
 	char BoardPtr = Pointer( chessman[ChessmanPtr].File, chessman[ChessmanPtr].Rank );
-	if( ( BoardPtr < 0 ) || ( BoardPtr > 63 ) ) return FALSE;
-	if( current[BoardPtr].ManPtr != ChessmanPtr ) return FALSE;
-	return TRUE;
+	if( ( BoardPtr < 0 ) || ( BoardPtr > 63 ) ) return false;
+	if( current[BoardPtr].ManPtr != ChessmanPtr ) return false;
+	return true;
 }
 ///////////////////////////////////////
 //
@@ -189,16 +189,16 @@ void logic::Init_Standard( void )
 ///////////////////////////////////////
 bool logic::parseCAN( const bool Army )
 {
-	if( chessMove.CAN == NULL ) return FALSE;
+	if( chessMove.CAN == NULL ) return false;
  	if( ( chessMove.CAN[0] != 'o' ) && ( chessMove.CAN[0] != 'O' ) )
  	{
-		if( ( chessMove.CAN[0] < 'a' ) || ( chessMove.CAN[0] > 'h' ) ) return FALSE;
+		if( ( chessMove.CAN[0] < 'a' ) || ( chessMove.CAN[0] > 'h' ) ) return false;
  		chessMove.fromFile = chessMove.CAN[0] - 97;
-		if( ( chessMove.CAN[1] < '1' ) || ( chessMove.CAN[1] > '8' ) ) return FALSE;
+		if( ( chessMove.CAN[1] < '1' ) || ( chessMove.CAN[1] > '8' ) ) return false;
  		chessMove.fromRank = chessMove.CAN[1] - 49;
-		if( ( chessMove.CAN[2] < 'a' ) || ( chessMove.CAN[2] > 'h' ) ) return FALSE;
+		if( ( chessMove.CAN[2] < 'a' ) || ( chessMove.CAN[2] > 'h' ) ) return false;
  		chessMove.toFile = chessMove.CAN[2] - 97;
-		if( ( chessMove.CAN[3] < '1' ) || ( chessMove.CAN[3] > '8' ) ) return FALSE;
+		if( ( chessMove.CAN[3] < '1' ) || ( chessMove.CAN[3] > '8' ) ) return false;
  		chessMove.toRank = chessMove.CAN[3] - 49;
 		if( strlen( chessMove.CAN ) == 5 ) chessMove.Promote = chessMove.CAN[4];
 		else chessMove.Promote = Null;
@@ -223,7 +223,7 @@ bool logic::parseCAN( const bool Army )
  			chessMove.toRank = 7;
  		}
  	}
-	return TRUE;
+	return true;
 }
 ///////////////////////////////////////
 //
@@ -333,7 +333,7 @@ bool logic::parseSAN( void )
 				}
 				/* Unknown symbol... Can not process this chessMove */
 //				kdDebug() << "logic::ParseSAN: Unknown Symbol: " << chessMove.SAN[SANPtr] << "\n";
-				return FALSE;
+				return false;
 				break;				
 		}
 		SANPtr++;
@@ -362,9 +362,9 @@ bool logic::parseSAN( void )
 //		kdWarning() << "logic::ParseSAN could not make a legal chessMove out of " << TQString( chessMove.SAN ) << endl;
 //		kdWarning() << (int)Army << " " << (int)Type << " " << (int)chessMove.fromFile << " " << (int)chessMove.fromRank
 //							<< " " << (int)chessMove.toFile << " " << (int)chessMove.toRank << endl;
-		return FALSE;
+		return false;
 	}
-	return TRUE;
+	return true;
 }
 ///////////////////////////////////////
 //
@@ -392,8 +392,8 @@ void logic::writeCAN( void )
 void logic::writeSAN( void )
 {
 	Position backup[64];
-	bool SANambig(FALSE);
-	bool SANambig2(FALSE);
+	bool SANambig(false);
+	bool SANambig2(false);
 	char tmp, manPtr, toPtr, fromPtr;
 	TQString SAN;
 
@@ -422,9 +422,9 @@ void logic::writeSAN( void )
 				HashLegal( tmp );
 				if( current[toPtr].Note >= NOTE_MOVE )
 				{
-					SANambig = TRUE;
+					SANambig = true;
 					if( chessman[tmp].File == chessman[manPtr].File )
-							SANambig2 = TRUE;
+							SANambig2 = true;
 				}
 			}
 			/*
@@ -440,8 +440,8 @@ void logic::writeSAN( void )
 								HashLegal( tmp );
 								if( current[toPtr].Note >= NOTE_MOVE )
 								{
-									SANambig = TRUE;
-									SANambig2 = TRUE;
+									SANambig = true;
+									SANambig2 = true;
 								}
 							}
 						}
@@ -453,7 +453,7 @@ void logic::writeSAN( void )
 				( current[toPtr].Note == NOTE_ENPASSANT ) ) &&
 				( chessman[manPtr].Type == Pawn ) )
 	{
-		SANambig = TRUE;
+		SANambig = true;
 	}
 	/* Write SAN Notation */
 	if( current[toPtr].Note == NOTE_CASTLE )
@@ -486,7 +486,7 @@ void logic::writeSAN( void )
 			default:
 				break;
 		}
-		if( SANambig == TRUE )
+		if( SANambig == true )
 		{
 			SAN += char( chessMove.fromFile + 97 );
 			if( SANambig2 ) SAN += char( chessMove.fromRank + 49 );
@@ -723,10 +723,10 @@ bool logic::isCheck( const bool Army )
 			if( isChessman( tmp ) )
 			{
 				HashLegal( tmp );
-				if( current[ currentKing ].Note == NOTE_ATTACK ) return TRUE;
+				if( current[ currentKing ].Note == NOTE_ATTACK ) return true;
 			}
 	}
-	return FALSE;
+	return false;
 }
 ///////////////////////////////////////
 //
@@ -747,10 +747,10 @@ bool logic::isLegal( const bool Army )
 				count = 0;
 				tmp = 0;
 				while( tmp < 64 ) count += ( current[tmp++].Note >= NOTE_MOVE );
-				if( count ) return TRUE;
+				if( count ) return true;
 			}
 	}
-	return FALSE;
+	return false;
 }
 ///////////////////////////////////////
 //
@@ -759,57 +759,57 @@ bool logic::isLegal( const bool Army )
 ///////////////////////////////////////
 bool logic::isDraw( const bool Army )
 {
-	bool haveBishop(FALSE);
-	bool haveBishopDiag(FALSE);
-	bool haveKnight(FALSE);
-	bool EnemyBishop(FALSE);
-	bool EnemyBishopDiag(TRUE);
-	bool EnemyKnight(FALSE);
+	bool haveBishop(false);
+	bool haveBishopDiag(false);
+	bool haveKnight(false);
+	bool EnemyBishop(false);
+	bool EnemyBishopDiag(true);
+	bool EnemyKnight(false);
 	int tmp(0);
 
-	if( !isLegal( Army ) ) return TRUE;
+	if( !isLegal( Army ) ) return true;
 	for( tmp = 0; tmp < 64; tmp++ )
 	{
 		if( !isChessman( tmp ) ) continue;
-		if( chessman[tmp].Type == Queen ) return FALSE;
-		if( chessman[tmp].Type == Pawn ) return FALSE;
-		if( chessman[tmp].Type == Rook ) return FALSE;
+		if( chessman[tmp].Type == Queen ) return false;
+		if( chessman[tmp].Type == Pawn ) return false;
+		if( chessman[tmp].Type == Rook ) return false;
 		/* Enemy guys */
 		if( chessman[tmp].Army != Army )
 		{
 			if( chessman[tmp].Type == Bishop )
 			{
-				if( EnemyBishop == TRUE ) return FALSE;
+				if( EnemyBishop == true ) return false;
 				EnemyBishopDiag = abs( ( current[tmp].Rank % 2 ) - ( current[tmp].File % 2 ) );
-				EnemyBishop = TRUE;
+				EnemyBishop = true;
 			}
 			if( chessman[tmp].Type == Knight )
 			{
-				if( EnemyKnight == TRUE ) return FALSE;
-				EnemyKnight = TRUE;
+				if( EnemyKnight == true ) return false;
+				EnemyKnight = true;
 			}			
 			continue;
 		}
 		/* Our guys */
 		if( chessman[tmp].Type == Bishop )
 		{
-			if( haveBishop == TRUE ) return FALSE;
+			if( haveBishop == true ) return false;
 			haveBishopDiag = abs( ( current[tmp].Rank % 2 ) - ( current[tmp].File % 2 ) );
-			haveBishop = TRUE;
+			haveBishop = true;
 		}
 		if( chessman[tmp].Type == Knight )
 		{
-			if( haveKnight == TRUE ) return FALSE;
-			haveKnight = TRUE;
+			if( haveKnight == true ) return false;
+			haveKnight = true;
 		}					
 	}
-	if( haveKnight && EnemyKnight ) return FALSE;
-	if( haveBishop && EnemyKnight ) return FALSE;
-	if( haveKnight && EnemyBishop ) return FALSE;
-	if( haveKnight && haveBishop ) return FALSE;
-	if( EnemyKnight && EnemyBishop ) return FALSE;
-	if( ( haveBishop && EnemyBishop ) && ( haveBishopDiag != EnemyBishopDiag ) ) return FALSE;
-	return TRUE;
+	if( haveKnight && EnemyKnight ) return false;
+	if( haveBishop && EnemyKnight ) return false;
+	if( haveKnight && EnemyBishop ) return false;
+	if( haveKnight && haveBishop ) return false;
+	if( EnemyKnight && EnemyBishop ) return false;
+	if( ( haveBishop && EnemyBishop ) && ( haveBishopDiag != EnemyBishopDiag ) ) return false;
+	return true;
 }
 ///////////////////////////////////////
 //
@@ -926,15 +926,15 @@ bool logic::Move( void )
 	fromPtr = Pointer( chessMove.fromFile, chessMove.fromRank );
 	toPtr = Pointer( chessMove.toFile, chessMove.toRank );
 	if( ( fromPtr == Null ) || ( toPtr == Null ) )
-		return FALSE;
+		return false;
 	manPtr = current[fromPtr].ManPtr;
 	if( manPtr == Null )
-		return FALSE;
+		return false;
 
 	HashLegal( manPtr );
 	/* Only proceed if this is a move */
 	if( current[toPtr].Note < NOTE_MOVE )
-		return FALSE; // This depends on all moves being higher value than NOTE_MOVE,
+		return false; // This depends on all moves being higher value than NOTE_MOVE,
 									// while all non-moves are less.
 
 	/* Take care of moving the rook in a caste */
@@ -986,7 +986,7 @@ bool logic::Move( void )
 				if( ( ( OnMove == WHITE ) && ( Param->type(WHITE) == PLAYERLOCAL ) ) ||
 						( ( OnMove == BLACK ) && ( Param->type(BLACK) == PLAYERLOCAL ) ) )
 						{
-							if( Resource->OPTION_Auto_Queen == TRUE ) chessMove.Promote = 'q';
+							if( Resource->OPTION_Auto_Queen == true ) chessMove.Promote = 'q';
 							else
 							{
 								/* Prompt user for promotion */
@@ -1028,7 +1028,7 @@ bool logic::Move( void )
 			CastleFlag[ chessman[manPtr].Army ] -= CF_RookQ;
 	if( ( chessman[manPtr].Type == Rook ) && ( chessMove.fromFile == 7 ) )
 			CastleFlag[ chessman[manPtr].Army ] -= CF_RookK;
-	return TRUE;
+	return true;
 }
 ///////////////////////////////////////
 //
@@ -1082,7 +1082,7 @@ void logic::_HashLegal( const bool Recursion )
 					hash[Ptr].Note = NOTE_ATTACK;
 					break;
 				}
-				if( Recursion == TRUE ) hash[Ptr].Note = NOTE_ATTACK;
+				if( Recursion == true ) hash[Ptr].Note = NOTE_ATTACK;
 				break;
 			}
 			/* Negitive Rank Movement */
@@ -1100,7 +1100,7 @@ void logic::_HashLegal( const bool Recursion )
 					hash[Ptr].Note = NOTE_ATTACK;
 					break;
 				}
-				if( Recursion == TRUE ) hash[Ptr].Note = NOTE_ATTACK;
+				if( Recursion == true ) hash[Ptr].Note = NOTE_ATTACK;
 				break;
 			}
 			/* Positive File Movement */
@@ -1118,7 +1118,7 @@ void logic::_HashLegal( const bool Recursion )
 					hash[Ptr].Note = NOTE_ATTACK;
 					break;
 				}
-				if( Recursion == TRUE ) hash[Ptr].Note = NOTE_ATTACK;
+				if( Recursion == true ) hash[Ptr].Note = NOTE_ATTACK;
 				break;
 			}
 			/* Negative File Movement */
@@ -1136,7 +1136,7 @@ void logic::_HashLegal( const bool Recursion )
 					hash[Ptr].Note = NOTE_ATTACK;
 					break;
 				}
-				if( Recursion == TRUE ) hash[Ptr].Note = NOTE_ATTACK;
+				if( Recursion == true ) hash[Ptr].Note = NOTE_ATTACK;
 				break;
 			}
 			if( chessman[ManPtr].Type == Rook ) break;
@@ -1157,7 +1157,7 @@ void logic::_HashLegal( const bool Recursion )
 					hash[Ptr].Note = NOTE_ATTACK;
 					break;
 				}
-				if( Recursion == TRUE ) hash[Ptr].Note = NOTE_ATTACK;
+				if( Recursion == true ) hash[Ptr].Note = NOTE_ATTACK;
 				break;
 			}
 			/* NW Movement */
@@ -1175,7 +1175,7 @@ void logic::_HashLegal( const bool Recursion )
 					hash[Ptr].Note = NOTE_ATTACK;
 					break;
 				}
-				if( Recursion == TRUE ) hash[Ptr].Note = NOTE_ATTACK;
+				if( Recursion == true ) hash[Ptr].Note = NOTE_ATTACK;
 				break;
 			}
 			/* SW Movement */
@@ -1193,7 +1193,7 @@ void logic::_HashLegal( const bool Recursion )
 					hash[Ptr].Note = NOTE_ATTACK;
 					break;
 				}
-				if( Recursion == TRUE ) hash[Ptr].Note = NOTE_ATTACK;
+				if( Recursion == true ) hash[Ptr].Note = NOTE_ATTACK;
 				break;
 			}
 			/* SE Movement */
@@ -1211,7 +1211,7 @@ void logic::_HashLegal( const bool Recursion )
 					hash[Ptr].Note = NOTE_ATTACK;
 					break;
 				}
-				if( Recursion == TRUE ) hash[Ptr].Note = NOTE_ATTACK;
+				if( Recursion == true ) hash[Ptr].Note = NOTE_ATTACK;
 				break;
 			}
 			break;
@@ -1254,7 +1254,7 @@ void logic::_HashLegal( const bool Recursion )
 						hash[Ptr].Note = NOTE_MOVE;
 					else
 					{
-						if( Recursion == TRUE )
+						if( Recursion == true )
 							hash[Ptr].Note = NOTE_ATTACK;
 						if( chessman[hash[Ptr].ManPtr].Army != chessman[ManPtr].Army )
 							hash[Ptr].Note = NOTE_ATTACK;
@@ -1274,7 +1274,7 @@ void logic::_HashLegal( const bool Recursion )
 					if( hash[Ptr].ManPtr == Null ) hash[Ptr].Note = NOTE_MOVE;
 					else
 					{
-						if( Recursion == TRUE ) hash[Ptr].Note = NOTE_ATTACK;
+						if( Recursion == true ) hash[Ptr].Note = NOTE_ATTACK;
 						if( chessman[hash[Ptr].ManPtr].Army != chessman[ManPtr].Army ) hash[Ptr].Note = NOTE_ATTACK;
 					}
 				}
@@ -1288,7 +1288,7 @@ void logic::_HashLegal( const bool Recursion )
 				if( ( dirR == 0 ) && ( dirF == 0 ) ) dirF++;
 			}
 			/* Check for castles */
-			if( Recursion == FALSE )
+			if( Recursion == false )
 			{
 				/* Can the King castle at all? */
 				if( CastleFlag[ chessman[ ManPtr ].Army ] & CF_King )
@@ -1329,7 +1329,7 @@ void logic::_HashLegal( const bool Recursion )
 			/* Get direction of movement */
 			if( chessman[ManPtr].Army == WHITE ) dirR = 1;
 			else dirR = -1;
-			if( Recursion == FALSE )
+			if( Recursion == false )
 			{
 				/* Forward 1 square */
 				Ptr = CalcPointer( 0, dirR );
@@ -1347,7 +1347,7 @@ void logic::_HashLegal( const bool Recursion )
 					}
 				}
 			}
-			if( Recursion == TRUE )
+			if( Recursion == true )
 			{
 				/* Attack Left */
 				Ptr = CalcPointer( -1, dirR );
@@ -1390,7 +1390,7 @@ void logic::_HashLegal( const bool Recursion )
 	/*                     THE MONSTER                      */
 	/* Remove all possible moves that would either put your */
 	/* king into check or wouldn't stop a check in progress */
-	if( Recursion == FALSE )
+	if( Recursion == false )
 	{
 		/* Make Backups */
 		copyPositions( hash, hashBackup );
@@ -1407,7 +1407,7 @@ void logic::_HashLegal( const bool Recursion )
 				if( !isChessman( tmp ) ) continue;
 				if( ( chessman[tmp].Army != chessman[ManPtr].Army ) && ( chessman[tmp].Type != Null ) )
 				{
-					HashLegal( tmp, TRUE );
+					HashLegal( tmp, true );
 					/* Is a check in progress? */
 					if( hash[ currentKing ].Note == NOTE_ATTACK )
 					{
@@ -1475,7 +1475,7 @@ void logic::_HashLegal( const bool Recursion )
 				if( chessman[tmp2].Army != chessman[ManPtr].Army )
 					if( isChessman( tmp2 ) )
 					{
-						HashLegal( tmp2, TRUE );
+						HashLegal( tmp2, true );
 						if( hash[ currentKing ].Note == NOTE_ATTACK )
 						{
 							hashBackup[tmp].Note = NOTE_NONE;
