@@ -80,7 +80,7 @@ int main(int argc, char *argv[])
 	}
 	/* Without this connection, the destructors are not called, and some
 			housecleaning ( like destroying child processes ) isn't done */
-	a.connect( &a, TQT_SIGNAL( shutDown () ), knights, TQT_SLOT( KillAll() ) );
-  a.connect( &a, SIGNAL( aboutToQuit() ), knights, SLOT( aboutToQuit() ) );
+	a.connect( &a, TQ_SIGNAL( shutDown () ), knights, TQ_SLOT( KillAll() ) );
+  a.connect( &a, TQ_SIGNAL( aboutToQuit() ), knights, TQ_SLOT( aboutToQuit() ) );
 	return a.exec();
 }
