@@ -15,7 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <tqcstring.h>
 #include <tqfile.h>
 #include <tqregexp.h>
@@ -214,7 +214,7 @@ void match_param::setTimer( void )
 {
 	if( TimerFlag ) return;
 	TQTimer::singleShot( 0, this, TQ_SLOT( slot_Timer() ) );
-	TimerFlag = TRUE;
+	TimerFlag = true;
 }
 
 ///////////////////////////////////////
@@ -225,7 +225,7 @@ void match_param::setTimer( void )
 void match_param::slot_Timer( void )
 {
 	emit valuesChanged();
-	TimerFlag = FALSE;
+	TimerFlag = false;
 }
 
 ///////////////////////////////////////
