@@ -27,7 +27,7 @@
 
 class proto_uci : public proto_base
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 											proto_uci( const int ID );
