@@ -28,7 +28,7 @@ class TQTimer;
 
 class proto_xboard : public proto_base
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 											proto_xboard( const int ID );
