@@ -15,13 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 /* KDE */
-#include <kstddirs.h>
-#include <kglobalsettings.h>
+#include <kstandarddirs.h>
+#include <tdeglobalsettings.h>
 #include <ksimpleconfig.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
 #include <kmdcodec.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 /* TQt */
 #include <tqdir.h>
 #include <tqimage.h>
@@ -44,11 +44,11 @@
 //	resource::resource
 //
 ///////////////////////////////////////
-resource::resource(KCmdLineArgs *args)
+resource::resource(TDECmdLineArgs *args)
 {
 	GlobalDataDir = "";
 	Widget_Height = 20; // prevents max_size error for thinbuttons on init
-	Icons = new KIconLoader( TQString( "knights" ) );
+	Icons = new TDEIconLoader( TQString( "knights" ) );
 	Audio = new audio();
 
 	/* Define ConsoleStyle, our RichText */
@@ -64,7 +64,7 @@ resource::resource(KCmdLineArgs *args)
 	/* Define GlobalDataDir... This is very important! */
 	GlobalDataDir = args->getOption( "d" );
 	if( GlobalDataDir.isEmpty() )
-		GlobalDataDir = KGlobal::dirs()->findResourceDir("data", "knights/splash.png") + "knights/";
+		GlobalDataDir = TDEGlobal::dirs()->findResourceDir("data", "knights/splash.png") + "knights/";
 	if( GlobalDataDir.isEmpty() )
 	{
 		kdWarning() << "resource::resource: Can not read GlobalDataDir from environment." << endl;
@@ -97,10 +97,10 @@ resource::~resource()
 	delete myAccel;
 
 	/* Remove temp files that we missed
-	TQStringList temps = KGlobal::dirs()->findAllResources("tmp","knights*");
+	TQStringList temps = TDEGlobal::dirs()->findAllResources("tmp","knights*");
 	for( int a=0; a < temps.count(); a++)
 	{
-		KIO::NetAccess::del( "file://" + temps[a] );
+		TDEIO::NetAccess::del( "file://" + temps[a] );
 	} */
 }
 ///////////////////////////////////////
@@ -138,7 +138,7 @@ void resource::ConfigRead( void )
 	CFG->setGroup( "Themes" );
 	CurrentBoard = CFG->readEntry( "CurrentBoard", "KBDefault.tar.gz" );
 	CurrentChessmen = CFG->readEntry( "CurrentChessmen", "KCDefault.tar.gz" );
-	OPTION_3DBoard = CFG->readBoolEntry( "Use3DBoard", FALSE );
+	OPTION_3DBoard = CFG->readBoolEntry( "Use3DBoard", false );
 	ThemeSize = CFG->readNumEntry( "Size", initSize );
 	if( ThemeSize > ( initSize + 16 ) )
 		ThemeSize = initSize;
@@ -154,44 +154,45 @@ void resource::ConfigRead( void )
 	Local_Player = CFG->readEntry( "UserName", sysName );
 	Config_Version = CFG->readNumEntry( "ConfigVersion", 0 );
 	OPTION_On_Init = CFG->readNumEntry( "OnInit", MENU_VS_PC );
-	OPTION_Auto_Queen = CFG->readBoolEntry( "AlwaysQueen", FALSE );
-	OPTION_Ponder = CFG->readBoolEntry( "Ponder", TRUE );
-	OPTION_Book_White = CFG->readBoolEntry( "BookWhite", FALSE );
-	OPTION_Book_Black = CFG->readBoolEntry( "BookBlack", FALSE );
-	OPTION_Pause_On_Minimize = CFG->readBoolEntry( "PauseOnMinimize", TRUE );
-	OPTION_Reuse_PGN = CFG->readBoolEntry( "ReusePGN", FALSE );
+	OPTION_Auto_Queen = CFG->readBoolEntry( "AlwaysQueen", false );
+	OPTION_Ponder = CFG->readBoolEntry( "Ponder", true );
+	OPTION_Book_White = CFG->readBoolEntry( "BookWhite", false );
+	OPTION_Book_Black = CFG->readBoolEntry( "BookBlack", false );
+	OPTION_Pause_On_Minimize = CFG->readBoolEntry( "PauseOnMinimize", true );
+	OPTION_Delete_Logs = CFG->readBoolEntry( "DeleteLogOnExit", false );
+	OPTION_Reuse_PGN = CFG->readBoolEntry( "ReusePGN", false );
 	PGN_Filename = CFG->readEntry( "PGNFilename", TQString() );
 	SCID_Image_Path = CFG->readEntry( "SCIDImages", TQString() );
-	OPTION_Auto_Close_Last_ICS = CFG->readBoolEntry( "AutoCloseLastICS", TRUE );
-	OPTION_Show_Extended_PGN = CFG->readEntry( "ShowExtendedPGN", FALSE );
-	OPTION_Auto_Call_Flag = CFG->readBoolEntry( "AutoCallFlag", TRUE );
+	OPTION_Auto_Close_Last_ICS = CFG->readBoolEntry( "AutoCloseLastICS", true );
+	OPTION_Show_Extended_PGN = CFG->readBoolEntry( "ShowExtendedPGN", false );
+	OPTION_Auto_Call_Flag = CFG->readBoolEntry( "AutoCallFlag", true );
 	Email_Command_Line = CFG->readEntry( "EmailCommandLine", TQString("kmail -s %s --attach %m %a") );
-	Accepted_License = CFG->readBoolEntry( "Alg2p", FALSE );
+	Accepted_License = CFG->readBoolEntry( "Alg2p", false );
 
 	/* Display */
-	OPTION_Show_Splash = CFG->readBoolEntry( "ShowSplash", TRUE );
-	OPTION_Auto_Preview = CFG->readBoolEntry( "AutoPreview", FALSE );
-	OPTION_Show_Last_Move = CFG->readBoolEntry( "ShowLastMove", TRUE );
-	OPTION_Animate_Moves = CFG->readBoolEntry( "AnimateMoves", FALSE );
-	OPTION_Show_Coord = CFG->readBoolEntry( "ShowCoord", FALSE );
+	OPTION_Show_Splash = CFG->readBoolEntry( "ShowSplash", true );
+	OPTION_Auto_Preview = CFG->readBoolEntry( "AutoPreview", false );
+	OPTION_Show_Last_Move = CFG->readBoolEntry( "ShowLastMove", true );
+	OPTION_Animate_Moves = CFG->readBoolEntry( "AnimateMoves", false );
+	OPTION_Show_Coord = CFG->readBoolEntry( "ShowCoord", false );
 	OPTION_Board_Orientation = CFG->readBoolEntry( "BoardOrientation", 0 );
 
 	/* ICS */
 	CFG->setGroup( "ICS" );
-	OPTION_Premove = CFG->readBoolEntry( "Premove", TRUE );
-	OPTION_Kibitz = CFG->readBoolEntry( "Kibitz", TRUE );
-	OPTION_Private = CFG->readBoolEntry( "Private", FALSE );
-	OPTION_Shout = CFG->readBoolEntry( "Shout", TRUE );
-	OPTION_Tell = CFG->readBoolEntry( "Tell", TRUE );
-	OPTION_Seek = CFG->readBoolEntry( "Seek", TRUE );
+	OPTION_Premove = CFG->readBoolEntry( "Premove", true );
+	OPTION_Kibitz = CFG->readBoolEntry( "Kibitz", true );
+	OPTION_Private = CFG->readBoolEntry( "Private", false );
+	OPTION_Shout = CFG->readBoolEntry( "Shout", true );
+	OPTION_Tell = CFG->readBoolEntry( "Tell", true );
+	OPTION_Seek = CFG->readBoolEntry( "Seek", true );
 	OPTION_Profanity = CFG->readNumEntry( "Profanity", 1 );
 	Seek_Timer = CFG->readNumEntry( "SeekTimer", 70 );
 
 	/* Audio */
 	CFG->setGroup( "Audio" );
-	OPTION_Audio = CFG->readBoolEntry( "useAudio", TRUE );
+	OPTION_Audio = CFG->readBoolEntry( "useAudio", true );
 	CurrentAudio = CFG->readEntry( "CurrentAudio", "KSDefault.tar.gz" );
-	OPTION_Audio_Current_Only = CFG->readBoolEntry( "AudioCurrentOnly", FALSE );
+	OPTION_Audio_Current_Only = CFG->readBoolEntry( "AudioCurrentOnly", false );
 	Audio_Volume = CFG->readNumEntry( "AudioVolume", 0 );
 	Audio->enabled = OPTION_Audio;
 	Audio->volume = Audio_Volume;
@@ -235,6 +236,7 @@ void resource::ConfigWrite( void )
 	CFG->writeEntry( "BookBlack", OPTION_Book_Black );
 	CFG->writeEntry( "BoardOrientation", OPTION_Board_Orientation );
 	CFG->writeEntry( "PauseOnMinimize", OPTION_Pause_On_Minimize );
+	CFG->writeEntry( "DeleteLogOnExit", OPTION_Delete_Logs );
 	CFG->writeEntry( "ReusePGN", OPTION_Reuse_PGN );
 	CFG->writeEntry( "PGNFilename", PGN_Filename );
 	CFG->writeEntry( "AutoCloseLastICS", OPTION_Auto_Close_Last_ICS );
@@ -267,7 +269,7 @@ void resource::ConfigWrite( void )
 	/* Notification Prompts */
 	CFG->setGroup( "Notification Messages" );
 	CFG->writeEntry( "PromptForSaving", PromptForSaving );
-	CFG->setReadOnly( FALSE );
+	CFG->setReadOnly( false );
 	if( CFG->isReadOnly() )
 		kdWarning() << "resource::ConfigWrite: Configuration is READ ONLY. Can not write changes." << endl;
 	CFG->sync();
@@ -290,7 +292,7 @@ void resource::ReadMatchParam( void )
 
 	/* Handle Time Controls */
 	buffer = CFG->readEntry( "WhiteTCP", "40,900,0" );
-	TCPs = TQStringList::split( TQString(","), buffer, FALSE );
+	TCPs = TQStringList::split( TQString(","), buffer, false );
 	for( TQSL_IT = TCPs.begin(); TQSL_IT != TCPs.end(); ++TQSL_IT )
 	{
 		tempTCP.Moves = (*TQSL_IT).toInt();
@@ -302,7 +304,7 @@ void resource::ReadMatchParam( void )
 	}
 	TCPs.clear();
 	buffer = CFG->readEntry( "BlackTCP", "40,900,0" );
-	TCPs = TQStringList::split( TQString(","), buffer, FALSE );
+	TCPs = TQStringList::split( TQString(","), buffer, false );
 	for( TQSL_IT = TCPs.begin(); TQSL_IT != TCPs.end(); ++TQSL_IT )
 	{
 		tempTCP.Moves = (*TQSL_IT).toInt();
@@ -384,7 +386,7 @@ void resource::ReadEngines( void )
 	buffer = CFG->readEntry( "Engines" );
 	if( buffer.isEmpty() ) return;
 
-	engineList = TQStringList::split( TQString(","), buffer, FALSE );
+	engineList = TQStringList::split( TQString(","), buffer, false );
 	for ( engineListIT = engineList.begin(); engineListIT != engineList.end(); ++engineListIT )
 	{
 		if( !CFG->hasGroup( (*engineListIT) ) ) continue;
@@ -450,7 +452,7 @@ void resource::ReadServers( void )
 	buffer = CFG->readEntry( "Servers" );
 	if( buffer.isEmpty() ) return;
 
-	serverList = TQStringList::split( TQString(","), buffer, FALSE );
+	serverList = TQStringList::split( TQString(","), buffer, false );
 	for ( serverListIT = serverList.begin(); serverListIT != serverList.end(); ++serverListIT )
 	{
 		if( !CFG->hasGroup( (*serverListIT) ) ) continue;
@@ -618,7 +620,7 @@ void resource::setAudio( int AudioIndex )
 ///////////////////////////////////////
 void resource::setTheme( int BoardIndex, int ChessmenIndex )
 {
-	static bool firstTime( TRUE );
+	static bool firstTime( true );
 	TQString boardURL;
 	TQString chessmenURL;
 	TQString boardConf;
@@ -657,13 +659,13 @@ void resource::setTheme( int BoardIndex, int ChessmenIndex )
 	}
 
 	/* load the theme.conf files */
-	if( !KIO::NetAccess::download( boardURL + "theme.conf", boardConf ) )
+	if( !TDEIO::NetAccess::download( boardURL + "theme.conf", boardConf ) )
 		kdWarning() << "Can not read theme.conf from " << boardURL << endl;
-	boardConfig = new KSimpleConfig( boardConf, TRUE );
+	boardConfig = new KSimpleConfig( boardConf, true );
 
-	if( !KIO::NetAccess::download( chessmenURL + "theme.conf", chessmenConf ) )
+	if( !TDEIO::NetAccess::download( chessmenURL + "theme.conf", chessmenConf ) )
 		kdWarning() << "Can not read theme.conf from " << chessmenURL << endl;
-	chessmenConfig = new KSimpleConfig( chessmenConf, TRUE );
+	chessmenConfig = new KSimpleConfig( chessmenConf, true );
 
 	/* Read the headers */
 	boardConfig->setGroup( "General" );
@@ -683,7 +685,7 @@ void resource::setTheme( int BoardIndex, int ChessmenIndex )
 
 	/* Load the Board */
 	boardConfig->setGroup( "2DBoard" );
-	ThemeBorder = boardConfig->readBoolEntry( "HaveBorder", FALSE );
+	ThemeBorder = boardConfig->readBoolEntry( "HaveBorder", false );
 	loadThemeItem( boardURL + boardConfig->readEntry("Light", "square.light.png"), pixCache->Orig_SquareLight );
 	loadThemeItem( boardURL + boardConfig->readEntry("Dark", "square.dark.png"), pixCache->Orig_SquareDark );
 	loadThemeItem( boardURL + boardConfig->readEntry("Select", "square.select.png"), pixCache->Orig_HighlightSelect );
@@ -718,14 +720,14 @@ void resource::setTheme( int BoardIndex, int ChessmenIndex )
 	/* Remove the theme.conf files */
 	delete boardConfig;
 	delete chessmenConfig;
-	KIO::NetAccess::removeTempFile( boardConf );
-	KIO::NetAccess::removeTempFile( chessmenConf );
+	TDEIO::NetAccess::removeTempFile( boardConf );
+	TDEIO::NetAccess::removeTempFile( chessmenConf );
 
 	/* Cleanup */
 	pixCache->clear();
 	TQApplication::restoreOverrideCursor();
 	pixCache->resize( ThemeSize );
-	firstTime = FALSE;
+	firstTime = false;
 	return;
 }
 ///////////////////////////////////////
@@ -737,11 +739,11 @@ void resource::loadThemeItem( const TQString &URL, TQImage &Image )
 {
 	TQString tempFile;
 	
-	if( KIO::NetAccess::download( URL, tempFile ) )
+	if( TDEIO::NetAccess::download( URL, tempFile ) )
 	{
 		if( !Image.load( tempFile ) )
 			kdError() << "resource::LoadThemeItem: Can not load " << tempFile << ", which comes from " << URL << endl;
-		KIO::NetAccess::removeTempFile( tempFile );
+		TDEIO::NetAccess::removeTempFile( tempFile );
 	}
 	else
 		kdError() << "resource::LoadThemeItem: Can not extract " << URL << endl;
@@ -774,7 +776,7 @@ void resource::resizeTheme( const int &size )
 ///////////////////////////////////////
 TQPixmap resource::LoadIcon( TQString Name, int Group )
 {
-	return Icons->loadIcon( Name, (KIcon::Group)Group );
+	return Icons->loadIcon( Name, (TDEIcon::Group)Group );
 }
 ///////////////////////////////////////
 //
@@ -869,7 +871,7 @@ void resource::WriteColors( void )
 ///////////////////////////////////////
 void resource::ReadFonts( void )
 {
-	TQFont Fixed = KGlobalSettings::fixedFont();
+	TQFont Fixed = TDEGlobalSettings::fixedFont();
 	CFG->setGroup( "Fonts" );
 	FONT_Standard = CFG->readFontEntry( "StandardFont", &Fixed );
 	FONT_PrivateTell = CFG->readFontEntry( "PrivateFont", &Fixed );
@@ -964,13 +966,13 @@ TQString resource::themeURL( const TQString theme )
 {
 	TQString fullURL;
 	fullURL = "tar:" + GlobalDataDir + "themes/" + theme;
-	if( !KIO::NetAccess::exists( fullURL ) )
+	if( !TDEIO::NetAccess::exists( fullURL ) )
 	{
 		fullURL = "tar:" + TQDir::currentDirPath() + "../media/" + theme;
-		if( !KIO::NetAccess::exists( fullURL ) )
+		if( !TDEIO::NetAccess::exists( fullURL ) )
 		{
 			fullURL = "tar:" + TQDir::homeDirPath() + "/.knights/" + theme;
-			if( !KIO::NetAccess::exists( fullURL ) )
+			if( !TDEIO::NetAccess::exists( fullURL ) )
 			{
 				kdWarning() << "The theme " << theme << " does not exist in any valid path." << endl;
 				return TQString();
